| Dmodel-class | R Documentation |
S4 class that organizes the various data inputs for the MSA model. MSAdata simply inherits the slots from 6 component classes:
Dmodel, Dstock, Dfishery, Dsurvey DCKMR, and Dtag, where the D- prefix denotes an object for data inputs (or model configuration).
For convenience, most arrays and matrices have the associated dimensions in the variable name. For example, Cobs_ymfr represents
observed catch with the dimension following the underscore, following this template:
y | Year |
m | Season |
a | Age |
r | Region |
f | Fishery |
i | Index |
s | Stock |
nyInteger, number of years
nmInteger, number of seasons
naInteger, number of ages. The first age class is zero and the last age class (plus group is age na - 1).
nlInteger, number of length bins. Set to zero if lengths are not modeled.
nrInteger, number of spatial regions
nsInteger, number of stocks
lbinVector of lower boundary of length bins. Length nl + 1
lmidVector of midpoint of length bins. Length nl
FmaxNumeric, maximum allowable instantaneous fishing mortality rate (units of per season). Defaults to 3.
y_phiInteger, the year from which to obtain values of natural mortality and fecundity for the unfished stock-recruit replacement line (phi). Relevant if natural mortality or fecundity are time-varying. Defaults to 1.
scale_sVector, length ns. Multiplicative scaling factor that informs relative stock size to aid parameter estimation. Larger values implies larger stocks. Default set to 1. See make_parameters().
nyinitInteger, number of years of spool-up to calculate equilibrium unfished and starting conditions for the population model to account for seasonal and spatial dynamics. The numerical spool-up is not needed when both nm = 1 and nr = 1, i.e., nyinit = 1. Otherwise, set to 2 * na by default.
conditionCharacter, either to specify the model estimates fishing mortality as a parameter ("F", default) or equal to the catch ("catch").
nitFInteger, number of iterations to solve Baranov catch equation from observed catch if condition = "catch". Defaults to 5.
y_Fmult_fInteger vector by fleet, the year in which to directly estimate F. Choose a year/season/region combination when the catch is average relative to the time series. Only used if condition = "F".
m_Fmult_fInteger vector by fleet, the season in which to directly estimate F. Choose a year/season/region combination when the catch is average relative to the time series. Only used if condition = "F".
r_Fmult_fInteger vector by fleet, the region in which to directly estimate F. Choose a year/season/region combination when the catch is average relative to the time series. Only used if condition = "F".
pbc_rdev_ysNumeric matrix, for the fraction of lognormal bias correction (-0.5 * sd_r^2) applied to the recruitment estimates in the model. Typically between 0-1, with default of 1.
pbc_initrdev_asNumeric matrix, for the fraction of lognormal bias correction (-0.5 * sd_r^2) applied to the initial abundance vector in the model. Typically between 0-1, with default of 1.
priorCharacter vector to be evaluated in the model to return the log prior for a parameter. See example in documentation for prior.
nyretInteger, number of recent years of data to remove from the likelihood for retrospective analysis (positive numbers). Default is zero.
MSAdata-class check_data() Dmodel-class Dstock-class Dfishery-class Dsurvey-class DCKMR-class Dtag-class
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.