| calc_nextN | R Documentation |
This function applies survival of the current abundance, advances age classes, re-distributes the stock using the movement matrix.
calc_nextN(
N,
surv,
na = dim(N)[1],
nr = dim(N)[2],
ns = dim(N)[3],
advance_age = TRUE,
mov = array(1/nr, c(na, nr, nr, ns)),
plusgroup = TRUE
)
N |
Abundance at current time step. Array |
surv |
Survival during the current time step. Array |
na |
Integer, number of age classes |
nr |
Integer, number of regions |
ns |
Integer, number of stocks |
advance_age |
Logical, whether the animals advance to their next age class |
mov |
Movement array in the next time step. Array |
plusgroup |
Logical, whether the last age class is an accumulator plus group. |
Abundance at the next time step. Array [a, r, s]
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.