View source: R/calc_population.R
| calc_phi_project | R Documentation |
Project a population forward in time using calc_population() with constant recruitment and
seasonal dynamics (growth, movement-by-season) to obtain per recruit parameters. Note that the fishing
mortality among fleets and stocks remain linked by matrix q_fs.
calc_phi_project(
ny,
nm,
na,
nf = 1,
nr,
ns = 1,
F_mfr = array(0, c(nm, nf, nr)),
sel_mafs = array(1, c(nm, na, nf, ns)),
fwt_mafs = array(1, c(nm, na, nf, ns)),
q_fs = matrix(1, nf, ns),
M_as,
mov_marrs,
mat_as,
fec_as,
m_spawn = 1,
m_advanceage = 1,
delta_s = rep(0, ns),
natal_rs = matrix(1, nr, ns),
recdist_rs = matrix(1/nr, nr, ns)
)
ny |
Integer, number of years for the projection |
nm |
Integer, number of seasons |
na |
Integer, number of age classes |
nf |
Integer, number of fleets |
nr |
Integer, number of regions |
ns |
Integer, number of stocks |
F_mfr |
Equilibrium fishing mortality (per season). Matrix |
sel_mafs |
Selectivity by season, age, fleet, stock. Array |
fwt_mafs |
Fishery weight array by season, age, fleet, stock. Array |
q_fs |
Relative catchability of stock |
M_as |
Natural mortality. Matrix |
mov_marrs |
Movement array |
mat_as |
Maturity at age. Matrix |
fec_as |
Fecundity at age. Matrix |
m_spawn |
Integer, season of spawning |
m_advanceage |
Integer, season at which to advance integer year age classes |
delta_s |
Numeric vector by |
natal_rs |
Matrix |
recdist_rs |
Matrix |
The initial population vector will be the survival at age evenly divided by the number of regions nr.
A named list returned by calc_population().
calc_phi_simple()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.