View source: R/calc_population.R
| calc_phi_simple | R Documentation |
Calculate spawners per recruit by individual stock. Appropriate for a population model with a single spatial area and an annual time steps, i.e. single season.
calc_phi_simple(Z, fec_a, mat_a, delta = 0)
calc_NPR(Z, na = length(Z), plusgroup = TRUE)
Z |
Total mortality at age |
fec_a |
Fecundity at age. Vector |
mat_a |
Maturity at age. Vector |
delta |
Fraction of season that elapses when spawning occurs, e.g., midseason spawning when |
na |
Integer, number of age classes |
plusgroup |
Logical, whether the largest age class is a plusgroup accumulator age |
calc_phi_simple() returns a numeric for the spawning biomass per recruit.
calc_NPR() returns a numeric, numbers per recruit at age
calc_phi_project()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.