check_data: Check dimensions and inputs in MSAdata object

View source: R/check-data.R

check_dataR Documentation

Check dimensions and inputs in MSAdata object

Description

Ensures that data inputs are of proper dimension. Whenever possible, default values are added to missing items.

Usage

check_data(MSAdata, silent = FALSE)

Arguments

MSAdata

S4 object containing data inputs. See MSAdata

silent

Logical, whether or not to report default values to the console

Value

An updated MSAdata object.

See Also

MSAdata


multiSA documentation built on March 21, 2026, 1:06 a.m.