| fit_MSA | R Documentation |
Wrapper function that calls RTMB to create the model and perform the numerical optimization
fit_MSA(
MSAdata,
parameters,
map = list(),
random = NULL,
run_model = TRUE,
do_sd = TRUE,
report = TRUE,
silent = FALSE,
control = list(iter.max = 2e+05, eval.max = 4e+05),
...
)
MSAdata |
Data object. Class MSAdata, validated by |
parameters |
List of parameters, e.g., returned by |
map |
List of parameters indicated whether they are fixed and how they are shared, e.g., returned by |
random |
Character vector indicating the parameters that are random effects, e.g., returned by |
run_model |
Logical, whether to fit the model through |
do_sd |
Logical, whether to calculate the standard errors with |
report |
Logical, whether to return the report list with |
silent |
Logical, whether to report progress to console. Not passed to |
control |
Passed to |
... |
Other arguments to |
A MSAassess object.
report() retrospective()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.