get_MSAdata: Retrieve data object used to fit model

View source: R/misc.R

get_MSAdataR Documentation

Retrieve data object used to fit model

Description

A convenient function to retrieve the data object used to fit the model. The object is embedded in an environment within the RTMB object.

Usage

get_MSAdata(MSAassess)

Arguments

MSAassess

MSAassess object returned by fit_MSA()

Value

MSAdata object


multiSA documentation built on March 21, 2026, 1:06 a.m.