| optimize_RTMB | R Documentation |
A convenient function that fits a RTMB model and calculates standard errors.
optimize_RTMB(
obj,
hessian = FALSE,
restart = 0,
do_sd = TRUE,
control = list(iter.max = 2e+05, eval.max = 4e+05),
lower = -Inf,
upper = Inf,
silent = FALSE
)
obj |
The list returned by |
hessian |
Logical, whether to pass the Hessian function |
restart |
Integer, the maximum number of additional attempts to fit the model. See details. |
do_sd |
Logical, whether to calculate standard errors through |
control |
List of options passed to |
lower |
Lower bounds of parameters passed to |
upper |
Upper bounds of parameters passed to |
silent |
Logical, whether to report progress to console |
Argument restart allows for recursive model fitting to obtain convergence, through the following procedure:
Optimize model with stats::nlminb().
Determine convergence, defined by RTMB::sdreport() by whether the Cholesky decomposition of the covariance matrix is possible.
If convergence is not achieved, jitter parameter estimates with multiplicative factor rlnorm(mean = 0, sd = 1e-3) and return to step 1.
A named list: "opt" is the output of stats::nlminb() and "SD" is the output of get_sdreport()
get_sdreport()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.