| plot-MSA-data | R Documentation |
A set of functions to plot data variables and predicted values (catch, age composition, etc.)
plot_catch(fit, f = 1, by = c("region", "stock"), prop = FALSE, annual = FALSE)
plot_index(fit, i = 1, zoom = FALSE)
plot_CAA(fit, f = 1, r = 1, do_mean = FALSE)
plot_CAL(fit, f = 1, r = 1, do_mean = FALSE)
plot_IAA(fit, i = 1, do_mean = FALSE)
plot_IAL(fit, i = 1, do_mean = FALSE)
plot_SC(fit, ff = 1, aa = 1, r = 1, prop = FALSE)
plot_tagmov(fit, s = 1, yy = 1, aa = 1)
fit |
MSAassess object returned by |
f |
Integer, indexes the fleet |
by |
Character to indicate dimension for multivariate plots |
prop |
Logical, whether to plot proportions (TRUE) or absolute numbers |
annual |
Logical, whether to plot annual values (summed over seasons) |
i |
Integer, indexes the survey |
zoom |
Logical, for |
r |
Integer, indexes the region |
do_mean |
Logical, whether to plot full compositions or time series of mean length or mean age |
ff |
Integer, indexes the aggregate fleet (for stock composition data) |
aa |
Integer, indexes the aggregate age class (for stock composition and tag data) |
s |
Integer, indexes the stock |
yy |
Integer, indexes the aggregate years (for the tag data) |
plot_catch plots the fishery catch by stock or region (either whole numbers or proportions)
plot_index plots indices of abundance
plot_CAA plots the fishery catch at age
plot_CAL plots the catch at length
plot_IAA plots the index age composition
plot_IAL plots the index length composition
plot_SC plots the stock composition
plot_tagmov plots the tag movements
Various base graphics plots
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.