| plot-MSA-state | R Documentation |
A set of functions to plot state variables (biomass, recruitment time series, etc.)
plot_S(fit, by = c("stock", "region"), r, s, prop = FALSE, facet_free = FALSE)
plot_B(fit, by = c("stock", "region"), r, s, prop = FALSE, facet_free = FALSE)
plot_R(fit, s)
plot_SRR(fit, s = 1, phi = TRUE)
plot_Rdev(fit, s = 1, log = TRUE)
plot_Fstock(fit, s, by = c("annual", "season"))
plot_self(fit, f = 1, type = c("length", "age"))
plot_seli(fit, i = 1)
plot_selstock(
fit,
s = 1,
by = c("annual", "season"),
plot2d = c("contour", "filled.contour"),
...
)
plot_N(fit, m = 1, r, s = 1, plot2d = c("contour", "filled.contour"), ...)
plot_V(fit, f = 1, by = c("stock", "region"), prop = FALSE, facet_free = FALSE)
plot_Ffleet(fit, f = 1)
plot_mov(fit, s = 1, y, a, palette = "Peach")
plot_recdist(fit, palette = "Peach")
fit |
MSAassess object returned by |
by |
Character to indicate whether to calculate selectivity from F per year or per season |
r |
Integer for the corresponding region |
s |
Integer for the corresponding stock |
prop |
Logical, whether to plot proportions (TRUE) or absolute numbers |
facet_free |
Logical, whether to allow the y-axis limits to vary by panel in facetted plots |
phi |
Logical, whether to plot unfished replacement line |
log |
Logical, whether to plot the natural logarithm of the response variable |
f |
Integer for the corresponding fleet |
type |
For |
i |
Integer for the corresponding survey |
plot2d |
Character, plotting function for either a |
... |
Other argument to the base graphics function |
m |
Integer for the corresponding season |
y |
Integer, year for plotting the movement matrix (last model year is the default) |
a |
Integer, corresponding age for plotting the movement matrix (age 1 is the default) |
palette |
Character, palette name to pass to |
plot_S plots spawning output by stock or region (either whole numbers or proportions for the latter)
plot_B plots total biomass by stock or region (either whole numbers or proportions for the latter)
plot_R plots recruitment by stock
plot_SRR plots the stock-recruitment relationship and history (realized recruitment) by stock
plot_Rdev plots recruitment deviations by stock
plot_Fstock plots apical instantaneous fishing mortality (per year or per season) by stock
plot_self plots fishery selectivity
plot_seli plots index selectivity
plot_selstock plots the realized selectivity from total catch and total abundance at age
plot_N reports total abundance at age
plot_V plots vulnerable biomass, availability to the fishery
plot_Ffleet plots apical instantaneous fishing mortality (per season) by fleet
plot_mov plots movement matrices and the corresponding equilibrium distribution in multi-area models
plot_recdist plots the distribution of recruitment for each stock
Various base graphics plots
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.