View source: R/retrospective.R
| retrospective | R Documentation |
Perform a retrospective analysis, successive removals of most recent years of data to evaluate consistency in model estimates of biomass, recruitment, etc.
The summary method returns Mohn's rho and the plot method generates a markdown report.
retrospective(MSAassess, yret = 0:5, cores = 1)
## S3 method for class 'MSAretro'
plot(
x,
var = c("S_yst", "R_yst", "F_yst", "log_rdev_yst", "VB_ymft"),
s = 1,
f = 1,
...
)
## S3 method for class 'MSAretro'
summary(object, by = c("stock", "fleet"), ...)
## S3 method for class 'MSAretro'
report(
object,
filename = "retro",
dir = tempdir(),
open_file = TRUE,
render_args = list(),
...
)
MSAassess |
MSAassess object |
yret |
Vector specifying the years (positive integers and include zero) to remove for the retrospective analysis |
cores |
Integer for the number of cores to use for parallel processing (snowfall package) |
x, object |
Output of |
var |
Character to indicate the metric, the item in the |
s |
Integer for the stock index to plot |
f |
Integer for the fleet index to plot |
... |
Not used |
by |
Character indicating whether to calculate to Mohn's rho on stock or fleet-based time series |
filename |
Character string for the name of the markdown and HTML files. |
dir |
The directory in which the markdown and HTML files will be saved. |
open_file |
Logical, whether the HTML document is opened after it is rendered. |
render_args |
List of arguments to pass to |
A MSAretro object containing a named lists of arrays generated by the retrospective analysis:
S_yst Spawning output array [y, s, t] where t indexes the retrospective peel
R_yst Recruitment array [y, s, t]
F_yst Apical fishing mortality [y, s, t]
VB_ymft Vulnerable biomass available to each fishery [y, m, f, t]
plot generic for MSAretro returns individual figures using base graphics.
summary generic for MSAretro returns a matrix of Mohn's rho.
report generic for MSAretro invisibly returns the output of rmarkdown::render(): character of the path of the rendered HTML markdown report.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.