| calc_recruitment | R Documentation |
Calculate recruitment from stock-recruit function
calc_recruitment(x, SRR = c("BH", "Ricker"), eq = FALSE, ...)
x |
Numeric, either the spawning output or the equilibrium spawners per recruit, from which
the recruitment will be calculated. See argument |
SRR |
Character to indicate the functional form of the stock recruit function |
eq |
Logical, indicates whether |
... |
Parameters of the SRR function. Provide one of two sets of variables:
|
Numeric of length x
calc_recruitment(10, SRR = "Ricker", a = 2, b = 0.5)
calc_recruitment(10, SRR = "Ricker", h = 0.9, R0 = 1, phi0 = 1)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.