powered by
Calculate recruitment from stock-recruit function
calc_recruitment(x, SRR = c("BH", "Ricker"), eq = FALSE, ...)
Numeric of length x
x
Numeric, either the spawning output or the equilibrium spawners per recruit, from which the recruitment will be calculated. See argument eq.
eq
Character to indicate the functional form of the stock recruit function
Logical, indicates whether x is the spawning output (FALSE) or equilibrium spawners per recruit (TRUE)
FALSE
TRUE
Parameters of the SRR function. Provide one of two sets of variables:
h, R0 and phi0, or
h
R0
phi0
a and b (alpha, beta values)
a
b
calc_recruitment(10, SRR = "Ricker", a = 2, b = 0.5) calc_recruitment(10, SRR = "Ricker", h = 0.9, R0 = 1, phi0 = 1)
Run the code above in your browser using DataLab