| check_data | R Documentation |
Ensures that data inputs are of proper dimension. Whenever possible, default values are added to missing items.
check_data(MSAdata, silent = FALSE)
MSAdata |
S4 object containing data inputs. See MSAdata |
silent |
Logical, whether or not to report default values to the console |
An updated MSAdata object.
MSAdata
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.