| get_MSAdata | R Documentation |
A convenient function to retrieve the data object used to fit the model. The object is embedded in an environment within the RTMB object.
get_MSAdata(MSAassess)
MSAassess |
MSAassess object returned by |
MSAdata object
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.