| softmax | R Documentation |
Takes a vector of real numbers and returns the corresponding vector of probabilities
softmax(eta, log = FALSE)
eta |
Vector |
log |
Logical, whether to return the value of the logarithm |
Uses multiSA:::logspace.add for numerical stability
Numeric, vector length of eta: \exp(\eta)/\sum\exp(\eta)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.